@@ -44,7 +44,7 @@ class PackageArrival(ArrivalShip):
     def __init__(self, pack: Package):
         super().__init__()
         head = pack.head
-        self.__sn = head.sn
+        self.__sn = head.sn.get_bytes()
         if head.is_fragment:
             self.__packer = Packer(sn=head.sn, pages=head.pages)
             self.__completed = self.__packer.insert(fragment=pack)
@@ -64,7 +64,7 @@ class PackageArrival(ArrivalShip):
             return packer.fragments
 
     @property  # Override
-    def sn(self) -> TransactionID:
+    def sn(self) -> bytes:
         return self.__sn
 
     # Override
@@ -85,6 +85,7 @@ class PackageDeparture(DepartureShip):
 
     def __init__(self, pack: Package, priority: int = 0, delegate: ShipDelegate = None):
         super().__init__(priority=priority, delegate=delegate)
+        self.__sn = pack.head.sn.get_bytes()
         self.__completed = pack
         self.__packages = self._split_package(pack=pack)
         self.__fragments: List[bytes] = []
@@ -101,8 +102,8 @@ class PackageDeparture(DepartureShip):
         return self.__completed
 
     @property  # Override
-    def sn(self) -> TransactionID:
-        return self.__completed.head.sn
+    def sn(self) -> bytes:
+        return self.__sn
 
     @property  # Override
     def fragments(self) -> List[bytes]:
@@ -258,15 +259,6 @@ class PackageDocker(StarDocker):
         pack = Package.new(data_type=DataType.MESSAGE_RESPONSE, sn=sn, pages=pages, index=index, body=Data(buffer=OK))
         self.send_package(pack=pack)
 
-    def send_package(self, pack: Package, priority: int = 0, delegate: ShipDelegate = None):
-        if delegate is None:
-            delegate = self.delegate
-        ship = self._create_departure(pack=pack, priority=priority, delegate=delegate)
-        self.append_departure(ship=ship)
-
-    def send_ship(self, ship: Departure):
-        self.append_departure(ship=ship)
-
     # Override
     def pack(self, payload: bytes, priority: int = 0, delegate: ShipDelegate = None) -> Departure:
         pkg = Package.new(data_type=DataType.MESSAGE, body=Data(buffer=payload))
@@ -276,7 +268,26 @@ class PackageDocker(StarDocker):
     def heartbeat(self):
         pkg = Package.new(data_type=DataType.COMMAND, body=Data(buffer=PING))
         outgo = self._create_departure(pack=pkg, priority=DeparturePriority.SLOWER)
-        self.append_departure(ship=outgo)
+        self.send_ship(ship=outgo)
+
+    #
+    #   Send
+    #
+
+    def send_ship(self, ship: Departure) -> bool:
+        return self.append_departure(ship=ship)
+
+    # def send_data(self, payload: bytes, priority: int = 0, delegate: Optional[ShipDelegate] = None) -> bool:
+    #     if delegate is None:
+    #         delegate = self.delegate
+    #     ship = self.pack(payload=payload, priority=priority, delegate=delegate)
+    #     return self.send_ship(ship=ship)
+
+    def send_package(self, pack: Package, priority: int = 0, delegate: ShipDelegate = None) -> bool:
+        if delegate is None:
+            delegate = self.delegate
+        ship = self._create_departure(pack=pack, priority=priority, delegate=delegate)
+        return self.send_ship(ship=ship)
 
 
 PING = b'PING'
